==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/AnalyticsConnectorDataLakeDataDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.AnalyticsConnectorDataLakeDataDestinationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The Data Lake data destination for Analytics Connector.
 * @property dataLakeName The name for the Data Lake.
 * @property name Name of data destination.
 * @property type Type of data destination.
 * Expected value is 'datalake'.
 */
public data class AnalyticsConnectorDataLakeDataDestinationArgs(
    public val dataLakeName: Output<String>,
    public val name: Output<String>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.AnalyticsConnectorDataLakeDataDestinationArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.AnalyticsConnectorDataLakeDataDestinationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.AnalyticsConnectorDataLakeDataDestinationArgs.builder()
            .dataLakeName(dataLakeName.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AnalyticsConnectorDataLakeDataDestinationArgs].
 */
@PulumiTagMarker
public class AnalyticsConnectorDataLakeDataDestinationArgsBuilder internal constructor() {
    private var dataLakeName: Output<String>? = null

    private var name: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The name for the Data Lake.
     */
    @JvmName("dhosfmwyqedvkagn")
    public suspend fun dataLakeName(`value`: Output<String>) {
        this.dataLakeName = value
    }

    /**
     * @param value Name of data destination.
     */
    @JvmName("jlmkydfmbaeuoufu")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Type of data destination.
     * Expected value is 'datalake'.
     */
    @JvmName("pantdssraygotogt")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The name for the Data Lake.
     */
    @JvmName("oukmlifoymhahcjs")
    public suspend fun dataLakeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataLakeName = mapped
    }

    /**
     * @param value Name of data destination.
     */
    @JvmName("iqaabagqxjnrilhu")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Type of data destination.
     * Expected value is 'datalake'.
     */
    @JvmName("tgsujcpajbauvtlg")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): AnalyticsConnectorDataLakeDataDestinationArgs =
        AnalyticsConnectorDataLakeDataDestinationArgs(
            dataLakeName = dataLakeName ?: throw PulumiNullFieldException("dataLakeName"),
            name = name,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/AnalyticsConnectorDataLakeDataDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.AnalyticsConnectorDataLakeDataDestinationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The Data Lake data destination for Analytics Connector.
 * @property dataLakeName The name for the Data Lake.
 * @property name Name of data destination.
 * @property type Type of data destination.
 * Expected value is 'datalake'.
 */
public data class AnalyticsConnectorDataLakeDataDestinationArgs(
    public val dataLakeName: Output<String>,
    public val name: Output<String>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.AnalyticsConnectorDataLakeDataDestinationArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.AnalyticsConnectorDataLakeDataDestinationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.AnalyticsConnectorDataLakeDataDestinationArgs.builder()
            .dataLakeName(dataLakeName.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AnalyticsConnectorDataLakeDataDestinationArgs].
 */
@PulumiTagMarker
public class AnalyticsConnectorDataLakeDataDestinationArgsBuilder internal constructor() {
    private var dataLakeName: Output<String>? = null

    private var name: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The name for the Data Lake.
     */
    @JvmName("pvgdthiihkmywcok")
    public suspend fun dataLakeName(`value`: Output<String>) {
        this.dataLakeName = value
    }

    /**
     * @param value Name of data destination.
     */
    @JvmName("foeuwdlvfxiucfcp")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Type of data destination.
     * Expected value is 'datalake'.
     */
    @JvmName("tjhwiunealwpsile")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The name for the Data Lake.
     */
    @JvmName("rcvjhchcenaldtbn")
    public suspend fun dataLakeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataLakeName = mapped
    }

    /**
     * @param value Name of data destination.
     */
    @JvmName("pnqsmnspsbikvdqe")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Type of data destination.
     * Expected value is 'datalake'.
     */
    @JvmName("rdtlwecomcwdafdd")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): AnalyticsConnectorDataLakeDataDestinationArgs =
        AnalyticsConnectorDataLakeDataDestinationArgs(
            dataLakeName = dataLakeName ?: throw PulumiNullFieldException("dataLakeName"),
            name = name,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}
